@@ -23,7 +23,7 @@ import websockets
 from websockets.exceptions import ConnectionClosedOK
 
 
-__version__ = '1.3.0'
+__version__ = '1.3.1'
 
 logger = logging.getLogger('websockets')
 logger.setLevel(logging.DEBUG if '--debug' in sys.argv else logging.INFO)
@@ -260,6 +260,7 @@ class Iskra(WebSocketClient):
         async with httpx.AsyncClient(
             http2=True,
             headers=headers,
+            timeout=60,
             base_url=self.upload_url
         ) as client:
             for files in slicing_window(metadata):
@@ -287,24 +288,25 @@ class Iskra(WebSocketClient):
         #   - is async, so it does not block the websocket ping
         #   - updates the progress granularly
         #   - does not http timeout
-        request = client.build_request(
-            method='POST',
-            url=file['path'],
-            headers={'x-mtime-ns': str(file['mtime_ns'])},
-            files={'file': open(file['path'], 'rb')},
-        )
-        data_stream = request.stream.body
+        with open(file['path'], 'rb') as f:
+            request = client.build_request(
+                method='POST',
+                url=file['path'],
+                headers={'x-mtime-ns': str(file['mtime_ns'])},
+                files={'file': f},
+            )
+            data_stream = request.stream.body
 
-        progress.total += len(data_stream) - file['size']
+            progress.total += len(data_stream) - file['size']
 
-        async def stream():
-            for chunk in slicing_window(data_stream, size=MEGA_BYTE):
-                progress.update(len(chunk))
-                yield chunk
+            async def stream():
+                for chunk in slicing_window(data_stream, size=MEGA_BYTE):
+                    progress.update(len(chunk))
+                    yield chunk
 
-        request.stream = AsyncIteratorStream(stream())
-        response = await client.send(request)
-        response.raise_for_status()
+            request.stream = AsyncIteratorStream(stream())
+            response = await client.send(request)
+            response.raise_for_status()
 
 
 # Introspection
